@@ -1,5 +1,4 @@
 //go:build sam && atsamd21 && feather_m0
-// +build sam,atsamd21,feather_m0
 
 package machine
 
@@ -77,7 +76,8 @@ var SPI0 = sercomSPIM4
 // I2S pins
 const (
 	I2S_SCK_PIN = PA10
-	I2S_SD_PIN  = PA08
+	I2S_SDO_PIN = PA08
+	I2S_SDI_PIN = NoPin
 	I2S_WS_PIN  = NoPin // TODO: figure out what this is on Feather M0.
 )
 
