@@ -67,7 +67,8 @@ var (
 // I2S pins
 const (
 	I2S_SCK_PIN = PA10
-	I2S_SD_PIN  = PA08
+	I2S_SDO_PIN = PA08
+	I2S_SDI_PIN = NoPin // TODO: figure out what this is on Trinket M0.
 	I2S_WS_PIN  = NoPin // TODO: figure out what this is on Trinket M0.
 )
 
