@@ -1,5 +1,4 @@
 //go:build !windows
-// +build !windows
 
 // Copyright 2011 The Go Authors. All rights reserved.
 // Use of this source code is governed by a BSD-style
@@ -8,8 +7,8 @@
 package os
 
 const (
-	PathSeparator     = '/' // OS-specific path separator
-	PathListSeparator = ':' // OS-specific path list separator
+	PathSeparator     = '/' // PathSeparator is the OS-specific path separator
+	PathListSeparator = ':' // PathListSeparator is the OS-specific path list separator
 )
 
 // IsPathSeparator reports whether c is a directory separator character.
